@@ -29,6 +29,7 @@
 #include "vtkPointLocator.h"
 #include "vtkNew.h"
 
+#include <algorithm>
 #include <ctype.h>
 
 
@@ -420,9 +421,9 @@ int vtkMoleculeReaderBase::MakeBonds(vtkPoints *newPts,
                                      vtkIdTypeArray *atype,
                                      vtkCellArray *newBonds)
 {
-  register int i, j, k;
-  register int nbonds;
-  register double dx, dy, dz;
+  int i, j, k;
+  int nbonds;
+  double dx, dy, dz;
   double max, dist, radius;
   double X[3], Y[3];
   vtkIdType bond[2];
