@@ -30,6 +30,8 @@
 
 #include "vtk_gl2ps.h"
 
+#include <sstream>
+
 //-----------------------------------------------------------------------------
 vtkStandardNewMacro(vtkGL2PSContextDevice2D)
 
@@ -134,8 +136,6 @@ void vtkGL2PSContextDevice2D::DrawPolygon(float *points, int n)
     }
 }
 
-
-
 //-----------------------------------------------------------------------------
 void vtkGL2PSContextDevice2D::DrawEllipseWedge(float x, float y,
                                                float outRx, float outRy,
@@ -149,7 +149,7 @@ void vtkGL2PSContextDevice2D::DrawEllipseWedge(float x, float y,
 
   // The path implementation can't handle start/stop angles. Defer to the
   // superclass in this case.
-  if (fabs(startAngle) > 1e-5 || fabs(stopAngle - 360.0) > 1e-5)
+  if (std::fabs(startAngle) > 1e-5f || std::fabs(stopAngle - 360.0f) > 1e-5f)
     {
     this->Superclass::DrawEllipseWedge(x, y, outRx, outRy, inRx, inRy,
                                        startAngle, stopAngle);
@@ -158,13 +158,23 @@ void vtkGL2PSContextDevice2D::DrawEllipseWedge(float x, float y,
   vtkNew<vtkPath> path;
   this->AddEllipseToPath(path.GetPointer(), 0.f, 0.f, outRx, outRy, false);
   this->AddEllipseToPath(path.GetPointer(), 0.f, 0.f, inRx, inRy, true);
-  this->TransformPath(path.GetPointer());
 
-  double origin[3] = {x, y, 0.f};
+  std::stringstream label;
+  label << "vtkGL2PSContextDevice2D::DrawEllipseWedge("
+        << x << ", " << y << ", " << outRx << ", " << outRy << ", "
+        << inRx << ", " << inRy << ", " << startAngle << ", " << stopAngle
+        << ") path:";
+
   unsigned char color[4];
   this->Brush->GetColor(color);
 
-  vtkGL2PSUtilities::DrawPath(path.GetPointer(), origin, origin, color);
+  double rasterPos[3] = {static_cast<double>(x), static_cast<double>(y), 0.};
+
+  this->TransformPoint(x, y);
+  double windowPos[3] = {static_cast<double>(x), static_cast<double>(y), 0.};
+
+  vtkGL2PSUtilities::DrawPath(path.GetPointer(), rasterPos, windowPos, color,
+                              NULL, 0.0, -1.f, label.str().c_str());
 }
 
 //-----------------------------------------------------------------------------
@@ -194,14 +204,27 @@ void vtkGL2PSContextDevice2D::DrawEllipticArc(float x, float y,
   // Fill
   unsigned char fillColor[4];
   this->Brush->GetColor(fillColor);
-  vtkGL2PSUtilities::DrawPath(path.GetPointer(), origin, origin, fillColor);
+
+  std::stringstream label;
+  label << "vtkGL2PSContextDevice2D::DrawEllipticArc("
+        << x << ", " << y << ", " << rx << ", " << ry << ", "
+        << startAngle << ", " << stopAngle << ") fill:";
+
+  vtkGL2PSUtilities::DrawPath(path.GetPointer(), origin, origin, fillColor,
+                              NULL, 0.0, -1.f, label.str().c_str());
 
   // and stroke
   unsigned char strokeColor[4];
   this->Pen->GetColor(strokeColor);
   float strokeWidth = this->Pen->GetWidth();
+
+  label.str("");
+  label.clear();
+  label << "vtkGL2PSContextDevice2D::DrawEllipticArc("
+        << x << ", " << y << ", " << rx << ", " << ry << ", "
+        << startAngle << ", " << stopAngle << ") stroke:";
   vtkGL2PSUtilities::DrawPath(path.GetPointer(), origin, origin, strokeColor,
-                              NULL, 0.0, strokeWidth);
+                              NULL, 0.0, strokeWidth, label.str().c_str());
 }
 
 //-----------------------------------------------------------------------------
@@ -220,6 +243,7 @@ void vtkGL2PSContextDevice2D::DrawString(float *point,
   vtkGL2PSUtilities::DrawString(string.utf8_str(), this->TextProp, p);
 }
 
+//-----------------------------------------------------------------------------
 void vtkGL2PSContextDevice2D::DrawMathTextString(float apoint[],
                                                  const vtkStdString &string)
 {
@@ -256,7 +280,8 @@ void vtkGL2PSContextDevice2D::DrawMathTextString(float apoint[],
   this->TransformPath(path.GetPointer());
 
   vtkGL2PSUtilities::DrawPath(path.GetPointer(), origin, origin, color, NULL,
-                              rotateAngle);
+                              rotateAngle, -1.f,
+                              ("Pathified string: " + string).c_str());
 }
 
 //-----------------------------------------------------------------------------
@@ -300,13 +325,17 @@ void vtkGL2PSContextDevice2D::DrawCrossMarkers(bool highlight, float *points,
                                                int n, unsigned char *colors,
                                                int nc_comps)
 {
-  float delta = this->GetPen()->GetWidth() * 0.475;
-
   float oldWidth = this->Pen->GetWidth();
   unsigned char oldColor[4];
   this->Pen->GetColor(oldColor);
   int oldLineType = this->Pen->GetLineType();
 
+  float halfWidth = oldWidth * 0.5f;
+  float deltaX = halfWidth;
+  float deltaY = halfWidth;
+
+  this->TransformSize(deltaX, deltaY);
+
   if (highlight)
     {
     this->Pen->SetWidth(1.5);
@@ -345,17 +374,17 @@ void vtkGL2PSContextDevice2D::DrawCrossMarkers(bool highlight, float *points,
       }
 
     // The first line of the cross:
-    curLine[0] = point[0] + delta;
-    curLine[1] = point[1] + delta;
-    curLine[2] = point[0] - delta;
-    curLine[3] = point[1] - delta;
+    curLine[0] = point[0] + deltaX;
+    curLine[1] = point[1] + deltaY;
+    curLine[2] = point[0] - deltaX;
+    curLine[3] = point[1] - deltaY;
     this->DrawPoly(curLine, 2);
 
     // And the second:
-    curLine[0] = point[0] + delta;
-    curLine[1] = point[1] - delta;
-    curLine[2] = point[0] - delta;
-    curLine[3] = point[1] + delta;
+    curLine[0] = point[0] + deltaX;
+    curLine[1] = point[1] - deltaY;
+    curLine[2] = point[0] - deltaX;
+    curLine[3] = point[1] + deltaY;
     this->DrawPoly(curLine, 2);
     }
 
@@ -369,13 +398,17 @@ void vtkGL2PSContextDevice2D::DrawPlusMarkers(bool highlight, float *points,
                                               int n, unsigned char *colors,
                                               int nc_comps)
 {
-  float delta = this->GetPen()->GetWidth() * 0.475;
-
   float oldWidth = this->Pen->GetWidth();
   unsigned char oldColor[4];
   this->Pen->GetColor(oldColor);
   int oldLineType = this->Pen->GetLineType();
 
+  float halfWidth = oldWidth * 0.5f;
+  float deltaX = halfWidth;
+  float deltaY = halfWidth;
+
+  this->TransformSize(deltaX, deltaY);
+
   if (highlight)
     {
     this->Pen->SetWidth(1.5);
@@ -414,17 +447,17 @@ void vtkGL2PSContextDevice2D::DrawPlusMarkers(bool highlight, float *points,
       }
 
     // The first line of the plus:
-    curLine[0] = point[0] - delta;
+    curLine[0] = point[0] - deltaX;
     curLine[1] = point[1];
-    curLine[2] = point[0] + delta;
+    curLine[2] = point[0] + deltaX;
     curLine[3] = point[1];
     this->DrawPoly(curLine, 2);
 
     // And the second:
     curLine[0] = point[0];
-    curLine[1] = point[1] - delta;
+    curLine[1] = point[1] - deltaY;
     curLine[2] = point[0];
-    curLine[3] = point[1] + delta;
+    curLine[3] = point[1] + deltaY;
     this->DrawPoly(curLine, 2);
     }
 
@@ -439,13 +472,17 @@ void vtkGL2PSContextDevice2D::DrawSquareMarkers(bool /*highlight*/,
                                                 int n, unsigned char *colors,
                                                 int nc_comps)
 {
-  float delta = this->GetPen()->GetWidth() * 0.475;
-
   unsigned char oldColor[4];
   this->Brush->GetColor(oldColor);
 
   this->Brush->SetColor(this->Pen->GetColor());
 
+  float halfWidth = this->GetPen()->GetWidth() * 0.5f;
+  float deltaX = halfWidth;
+  float deltaY = halfWidth;
+
+  this->TransformSize(deltaX, deltaY);
+
   float quad[8];
   unsigned char color[4];
   for (int i = 0; i < n; ++i)
@@ -473,12 +510,12 @@ void vtkGL2PSContextDevice2D::DrawSquareMarkers(bool /*highlight*/,
       this->Brush->SetColor(color);
       }
 
-    quad[0] = point[0] - delta;
-    quad[1] = point[1] - delta;
-    quad[2] = point[0] + delta;
+    quad[0] = point[0] - deltaX;
+    quad[1] = point[1] - deltaY;
+    quad[2] = point[0] + deltaX;
     quad[3] = quad[1];
     quad[4] = quad[2];
-    quad[5] = point[1] + delta;
+    quad[5] = point[1] + deltaY;
     quad[6] = quad[0];
     quad[7] = quad[5];
 
@@ -540,13 +577,17 @@ void vtkGL2PSContextDevice2D::DrawDiamondMarkers(bool /*highlight*/,
                                                  int n, unsigned char *colors,
                                                  int nc_comps)
 {
-  float delta = this->GetPen()->GetWidth() * 0.475;
-
   unsigned char oldColor[4];
   this->Brush->GetColor(oldColor);
 
   this->Brush->SetColor(this->Pen->GetColor());
 
+  float halfWidth = this->GetPen()->GetWidth() * 0.5f;
+  float deltaX = halfWidth;
+  float deltaY = halfWidth;
+
+  this->TransformSize(deltaX, deltaY);
+
   float quad[8];
   unsigned char color[4];
   for (int i = 0; i < n; ++i)
@@ -574,14 +615,14 @@ void vtkGL2PSContextDevice2D::DrawDiamondMarkers(bool /*highlight*/,
       this->Brush->SetColor(color);
       }
 
-    quad[0] = point[0] - delta;
+    quad[0] = point[0] - deltaX;
     quad[1] = point[1];
     quad[2] = point[0];
-    quad[3] = point[1] - delta;
-    quad[4] = point[0] + delta;
+    quad[3] = point[1] - deltaY;
+    quad[4] = point[0] + deltaX;
     quad[5] = point[1];
     quad[6] = point[0];
-    quad[7] = point[1] + delta;
+    quad[7] = point[1] + deltaY;
 
     this->DrawQuad(quad,4);
     }
@@ -642,7 +683,7 @@ void vtkGL2PSContextDevice2D::AddEllipseToPath(vtkPath *path, float x, float y,
 }
 
 //-----------------------------------------------------------------------------
-void vtkGL2PSContextDevice2D::TransformPath(vtkPath *path)
+void vtkGL2PSContextDevice2D::TransformPath(vtkPath *path) const
 {
   // Transform the path with the modelview matrix:
   float modelview[16];
@@ -662,6 +703,28 @@ void vtkGL2PSContextDevice2D::TransformPath(vtkPath *path)
     }
 }
 
+//-----------------------------------------------------------------------------
+void vtkGL2PSContextDevice2D::TransformPoint(float &x, float &y) const
+{
+  float modelview[16];
+  glGetFloatv(GL_MODELVIEW_MATRIX, modelview);
+
+  float inX = x;
+  float inY = y;
+  x = modelview[0] * inX + modelview[4] * inY + modelview[12];
+  y = modelview[1] * inX + modelview[5] * inY + modelview[13];
+}
+
+//-----------------------------------------------------------------------------
+void vtkGL2PSContextDevice2D::TransformSize(float &dx, float &dy) const
+{
+  float modelview[16];
+  glGetFloatv(GL_MODELVIEW_MATRIX, modelview);
+
+  dx /= modelview[0];
+  dy /= modelview[5];
+}
+
 //-----------------------------------------------------------------------------
 void vtkGL2PSContextDevice2D::PrintSelf(ostream &os, vtkIndent indent)
 {
