@@ -16,14 +16,13 @@
 
 #include "vtkObjectFactory.h"
 #include "vtkWindowToImageFilter.h"
+#include "vtkPNGReader.h"
 #include "vtkPNGWriter.h"
 #include "vtkImageShiftScale.h"
 #include "vtkImageDifference.h"
-#include "vtkPNGReader.h"
 #include "vtkRenderWindow.h"
 #include "vtkImageData.h"
 #include "vtkTimerLog.h"
-#include "vtkSmartPointer.h"
 #include "vtkNew.h"
 #include "vtkRenderWindowInteractor.h"
 #include "vtkInteractorEventRecorder.h"
@@ -37,11 +36,6 @@
 #include "vtkFloatArray.h"
 #include "vtkStreamingDemandDrivenPipeline.h"
 #include "vtkInformation.h"
-#include "vtkAlgorithm.h"
-
-#include "vtkSmartPointer.h"
-#define VTK_CREATE(type, name) \
-  vtkSmartPointer<type> name = vtkSmartPointer<type>::New()
 
 #include <sys/stat.h>
 
@@ -57,7 +51,7 @@ using std::string;
 // Find in command tail, failing that find in environment,
 // failing that return a default.
 // Up to caller to delete the string returned.
-string vtkTestingGetArgOrEnvOrDefault(
+static string vtkTestingGetArgOrEnvOrDefault(
           string argName,       // argument idnetifier flag. eg "-D"
           vector<string> &argv, // command tail
           string env,           // environment variable name to find
@@ -66,12 +60,12 @@ string vtkTestingGetArgOrEnvOrDefault(
   string argValue;
 
   // Serach command tail.
-  int argc=static_cast<int>(argv.size());
-  for (int i=0; i<argc; i++)
+  int argc = static_cast<int>(argv.size());
+  for (int i = 0; i < argc; i++)
     {
-    if (argName==argv[i] && i<(argc-1))
+    if (argName == argv[i] && i < (argc - 1))
       {
-      argValue=argv[i+1];
+      argValue = argv[i + 1];
       }
     }
   // If not found search environment.
@@ -81,12 +75,12 @@ string vtkTestingGetArgOrEnvOrDefault(
     char *foundenv=getenv(env.c_str());
     if (foundenv)
       {
-      argValue=foundenv;
+      argValue = foundenv;
       }
     else
       {
       // Not found, fall back to default.
-      argValue=def;
+      argValue = def;
       }
     }
 
@@ -108,24 +102,24 @@ vtkIdType AccumulateScaledL2Norm(
         double &SumModR) // result
 {
   //
-  SumModR=0.0;
-  for (vtkIdType i=0; i<nTups; ++i)
+  SumModR = 0.0;
+  for (vtkIdType i = 0; i < nTups; ++i)
     {
-    double modR=0.0;
-    double modA=0.0;
-    for (int q=0; q<nComps; ++q)
+    double modR = 0.0;
+    double modA = 0.0;
+    for (int q = 0; q < nComps; ++q)
       {
-      double a=pA[q];
-      double b=pB[q];
-      modA+=a*a;
-      double r=b-a;
-      modR+=r*r;
+      double a = pA[q];
+      double b = pB[q];
+      modA += a * a;
+      double r = b - a;
+      modR += r * r;
       }
-    modA=sqrt(modA);
-    modA= modA<1.0 ? 1.0 : modA;
-    SumModR+=sqrt(modR)/modA;
-    pA+=nComps;
-    pB+=nComps;
+    modA = sqrt(modA);
+    modA = modA<1.0 ? 1.0 : modA;
+    SumModR += sqrt(modR) / modA;
+    pA += nComps;
+    pB += nComps;
     }
   return nTups;
 }
@@ -146,6 +140,7 @@ vtkTesting::vtkTesting()
   this->StartCPUTime = vtkTimerLog::GetCPUTime();
   this->StartWallTime = vtkTimerLog::GetUniversalTime();
 }
+
 //-----------------------------------------------------------------------------
 vtkTesting::~vtkTesting()
 {
@@ -154,15 +149,17 @@ vtkTesting::~vtkTesting()
   this->SetDataRoot(0);
   this->SetTempDirectory(0);
 }
+
 //-----------------------------------------------------------------------------
 void vtkTesting::AddArgument(const char *arg)
 {
   this->Args.push_back(arg);
 }
+
 //-----------------------------------------------------------------------------
-void vtkTesting::AddArguments(int argc,const char **argv)
+void vtkTesting::AddArguments(int argc, const char **argv)
 {
-  for (int i=0; i<argc; ++i)
+  for (int i = 0; i < argc; ++i)
     {
     this->Args.push_back(argv[i]);
     }
@@ -171,10 +168,10 @@ void vtkTesting::AddArguments(int argc,const char **argv)
 char *vtkTesting::GetArgument(const char *argName)
 {
   string argValue
-    = vtkTestingGetArgOrEnvOrDefault(argName,this->Args,"","");
+    = vtkTestingGetArgOrEnvOrDefault(argName, this->Args, "", "");
 
-  char *cArgValue=new char [argValue.size()+1];
-  strcpy(cArgValue,argValue.c_str());
+  char *cArgValue = new char[argValue.size() + 1];
+  strcpy(cArgValue, argValue.c_str());
 
   return cArgValue;
 }
@@ -220,24 +217,24 @@ const char *vtkTesting::GetValidImageFileName()
   string baseline=vtkTestingGetArgOrEnvOrDefault(
                 "-B", this->Args,"VTK_BASELINE_ROOT", this->GetDataRoot());
 
-  for (size_t i=0; i<(this->Args.size()-1); ++i)
+  for (size_t i = 0; i < (this->Args.size() - 1); ++i)
     {
-    if ( this->Args[i] == "-V")
+    if (this->Args[i] == "-V")
       {
-      const char *ch = this->Args[i+1].c_str();
-      if ( ch[0] == '/'
+      const char *ch = this->Args[i + 1].c_str();
+      if (ch[0] == '/'
 #ifdef _WIN32
-        || (ch[0] >= 'a' && ch[0] <= 'z' && ch[1] == ':' )
-        || (ch[0] >= 'A' && ch[0] <= 'Z' && ch[1] == ':' )
+        || (ch[0] >= 'a' && ch[0] <= 'z' && ch[1] == ':')
+        || (ch[0] >= 'A' && ch[0] <= 'Z' && ch[1] == ':')
 #endif
         )
         {
-        baseline = this->Args[i+1];
+        baseline = this->Args[i + 1];
         }
       else
         {
         baseline += "/";
-        baseline += this->Args[i+1];
+        baseline += this->Args[i + 1];
         }
       break;
       }
@@ -250,10 +247,9 @@ const char *vtkTesting::GetValidImageFileName()
 //-----------------------------------------------------------------------------
 int vtkTesting::IsInteractiveModeSpecified()
 {
-  unsigned int i;
-  for (i = 0; i < this->Args.size(); ++i)
+  for (size_t i = 0; i < this->Args.size(); ++i)
     {
-    if ( this->Args[i] == "-I")
+    if (this->Args[i] == "-I")
       {
       return 1;
       }
@@ -263,10 +259,9 @@ int vtkTesting::IsInteractiveModeSpecified()
 //-----------------------------------------------------------------------------
 int vtkTesting::IsFlagSpecified(const char *flag)
 {
-  unsigned int i;
-  for (i = 0; i < this->Args.size(); ++i)
+  for (size_t i = 0; i < this->Args.size(); ++i)
     {
-    if ( this->Args[i] == flag)
+    if (this->Args[i] == flag)
       {
       return 1;
       }
@@ -276,10 +271,9 @@ int vtkTesting::IsFlagSpecified(const char *flag)
 //-----------------------------------------------------------------------------
 int vtkTesting::IsValidImageSpecified()
 {
-  unsigned int i;
-  for (i = 1; i < this->Args.size(); ++i)
+  for (size_t i = 1; i < this->Args.size(); ++i)
     {
-    if ( this->Args[i-1] == "-V")
+    if (this->Args[i-1] == "-V")
       {
       return 1;
       }
@@ -298,16 +292,17 @@ char* vtkTesting::IncrementFileName(const char* fname, int count)
     return 0;
     }
   int extLen = static_cast<int>(strlen(counts));
-  char* newFileName = new char[orgLen+extLen+2];
+  char* newFileName = new char[orgLen + extLen + 2];
   strcpy(newFileName, fname);
 
-  newFileName[orgLen-4] = '_';
+  newFileName[orgLen - 4] = '_';
   int i, marker;
-  for(marker=orgLen-3, i=0; marker < orgLen-3+extLen; marker++, i++)
+  for (marker = orgLen - 3, i = 0; marker < orgLen - 3 + extLen;
+       marker++, i++)
     {
     newFileName[marker] = counts[i];
     }
-  strcpy( newFileName + marker, ".png" );
+  strcpy(newFileName + marker, ".png");
 
   return newFileName;
 }
@@ -359,46 +354,45 @@ int vtkTesting::RegressionTest(double thresh)
 //-----------------------------------------------------------------------------
 int vtkTesting::RegressionTest(double thresh, ostream &os)
 {
-  VTK_CREATE(vtkWindowToImageFilter, rt_w2if);
-  rt_w2if->SetInput(this->RenderWindow);
+  vtkNew<vtkWindowToImageFilter> rtW2if;
+  rtW2if->SetInput(this->RenderWindow);
 
-  unsigned int i;
-  for (i=0; i<this->Args.size(); i++)
+  for (unsigned int i = 0; i < this->Args.size(); ++i)
     {
-    if ( strcmp("-FrontBuffer", this->Args[i].c_str()) == 0 )
+    if ("-FrontBuffer" == this->Args[i])
       {
       this->FrontBufferOn();
       }
-    else if ( strcmp("-NoRerender", this->Args[i].c_str()) == 0 )
+    else if ("-NoRerender" == this->Args[i])
       {
-      rt_w2if->ShouldRerenderOff();
+      rtW2if->ShouldRerenderOff();
       }
     }
 
   // perform and extra render to make sure it is displayed
-  if ( !this->FrontBuffer)
+  if (!this->FrontBuffer)
     {
     this->RenderWindow->Render();
     // tell it to read the back buffer
-    rt_w2if->ReadFrontBufferOff();
+    rtW2if->ReadFrontBufferOff();
     }
   else
     {
     // read the front buffer
-    rt_w2if->ReadFrontBufferOn();
+    rtW2if->ReadFrontBufferOn();
     }
 
-  rt_w2if->Update();
-  int res = this->RegressionTest(rt_w2if, thresh, os);
+  rtW2if->Update();
+  int res = this->RegressionTest(rtW2if.Get(), thresh, os);
   return res;
 }
 //-----------------------------------------------------------------------------
-int vtkTesting::RegressionTest(const std::string &pngFileName, double thresh)
+int vtkTesting::RegressionTest(const string &pngFileName, double thresh)
 {
   return this->RegressionTest(pngFileName, thresh, cout);
 }
 //-----------------------------------------------------------------------------
-int vtkTesting::RegressionTest(const std::string &pngFileName, double thresh,
+int vtkTesting::RegressionTest(const string &pngFileName, double thresh,
                                ostream &os)
 {
   vtkNew<vtkPNGReader> inputReader;
@@ -413,48 +407,48 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
 {
   // do a get to compute the real value
   this->GetValidImageFileName();
-  std::string tmpDir = this->GetTempDirectory();
+  string tmpDir = this->GetTempDirectory();
 
   // construct the names for the error images
-  std::string validName = this->ValidImageFileName;
-  std::string::size_type slash_pos = validName.rfind("/");
-  if(slash_pos != std::string::npos)
+  string validName = this->ValidImageFileName;
+  string::size_type slashPos = validName.rfind("/");
+  if (slashPos != string::npos)
     {
-    validName = validName.substr(slash_pos + 1);
+    validName = validName.substr(slashPos + 1);
     }
 
   // check the valid image
-  FILE *rt_fin = fopen(this->ValidImageFileName,"r");
-  if (rt_fin)
+  FILE *rtFin = fopen(this->ValidImageFileName, "r");
+  if (rtFin)
     {
-    fclose(rt_fin);
+    fclose(rtFin);
     }
   else // there was no valid image, so write one to the temp dir
     {
-    std::string vImage = tmpDir + "/" + validName;
-    VTK_CREATE(vtkPNGWriter, rt_pngw);
-    rt_pngw->SetFileName(vImage.c_str());
-    rt_pngw->SetInputConnection(imageSource->GetOutputPort());
-    rt_pngw->Write();
+    string vImage = tmpDir + "/" + validName;
+    vtkNew<vtkPNGWriter> rtPngw;
+    rtPngw->SetFileName(vImage.c_str());
+    rtPngw->SetInputConnection(imageSource->GetOutputPort());
+    rtPngw->Write();
     os << "<DartMeasurement name=\"ImageNotFound\" type=\"text/string\">"
-      << this->ValidImageFileName << "</DartMeasurement>" << endl;
+       << this->ValidImageFileName << "</DartMeasurement>" << endl;
     return FAILED;
     }
 
-  VTK_CREATE(vtkPNGReader, rt_png);
-  rt_png->SetFileName(this->ValidImageFileName);
-  rt_png->Update();
+  vtkNew<vtkPNGReader> rtPng;
+  rtPng->SetFileName(this->ValidImageFileName);
+  rtPng->Update();
   imageSource->Update();
 
-  VTK_CREATE(vtkImageDifference, rt_id);
+  vtkNew<vtkImageDifference> rtId;
 
-  VTK_CREATE(vtkImageClip, ic1);
+  vtkNew<vtkImageClip> ic1;
   ic1->SetClipData(1);
   ic1->SetInputConnection(imageSource->GetOutputPort());
 
-  VTK_CREATE(vtkImageClip, ic2);
+  vtkNew<vtkImageClip> ic2;
   ic2->SetClipData(1);
-  ic2->SetInputConnection(rt_png->GetOutputPort());
+  ic2->SetInputConnection(rtPng->GetOutputPort());
 
   int* wExt1 = ic1->GetInputInformation()->Get(
     vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT());
@@ -475,10 +469,10 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
                             wExt2[5]);
 
   int ext1[6], ext2[6];
-  rt_id->SetInputConnection(ic1->GetOutputPort());
+  rtId->SetInputConnection(ic1->GetOutputPort());
   ic1->Update();
   ic1->GetOutput()->GetExtent(ext1);
-  rt_id->SetImageConnection(ic2->GetOutputPort());
+  rtId->SetImageConnection(ic2->GetOutputPort());
   ic2->Update();
   ic2->GetOutput()->GetExtent(ext2);
 
@@ -489,8 +483,8 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
       (ext2[5]-ext2[4]) == (ext1[5]-ext1[4]))
     {
     // Cannot compute difference unless image sizes are the same
-    rt_id->Update();
-    minError = rt_id->GetThresholdedError();
+    rtId->Update();
+    minError = rtId->GetThresholdedError();
     }
 
   this->ImageDifference = minError;
@@ -499,12 +493,12 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
     {
     // Make sure there was actually a difference image before
     // accepting the error measure.
-    vtkImageData* output = rt_id->GetOutput();
-    if(output)
+    vtkImageData* output = rtId->GetOutput();
+    if (output)
       {
       int dims[3];
       output->GetDimensions(dims);
-      if(dims[0]*dims[1]*dims[2] > 0)
+      if(dims[0] * dims[1] * dims[2] > 0)
         {
         passed = 1;
         }
@@ -523,7 +517,7 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
   // images of the form foo_N.png (where N=1,2,3...) and compare against
   // them.
   double error;
-  int count=1, errIndex=-1;
+  int count = 1, errIndex = -1;
   char* newFileName;
   while (!passed)
     {
@@ -534,7 +528,7 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
       break;
       }
 
-    rt_png->SetFileName(newFileName);
+    rtPng->SetFileName(newFileName);
 
     // Need to reset the output whole extent cause we may have baselines
     // of differing sizes. (Yes, we have such cases !)
@@ -547,14 +541,14 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
                               wExt2[5]);
     ic2->UpdateWholeExtent();
 
-    rt_id->GetImage()->GetExtent(ext2);
-    if ((ext2[1]-ext2[0]) == (ext1[1]-ext1[0]) &&
-        (ext2[3]-ext2[2]) == (ext1[3]-ext1[2]) &&
-        (ext2[5]-ext2[4]) == (ext1[5]-ext1[4]))
+    rtId->GetImage()->GetExtent(ext2);
+    if ((ext2[1] - ext2[0]) == (ext1[1] - ext1[0]) &&
+        (ext2[3] - ext2[2]) == (ext1[3] - ext1[2]) &&
+        (ext2[5] - ext2[4]) == (ext1[5] - ext1[4]))
       {
       // Cannot compute difference unless image sizes are the same
-      rt_id->Update();
-      error = rt_id->GetThresholdedError();
+      rtId->Update();
+      error = rtId->GetThresholdedError();
       }
     else
       {
@@ -565,12 +559,12 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
       {
       // Make sure there was actually a difference image before
       // accepting the error measure.
-      vtkImageData* output = rt_id->GetOutput();
-      if(output)
+      vtkImageData* output = rtId->GetOutput();
+      if (output)
         {
         int dims[3];
         output->GetDimensions(dims);
-        if(dims[0]*dims[1]*dims[2] > 0)
+        if (dims[0] * dims[1] * dims[2] > 0)
           {
           minError = error;
           passed = 1;
@@ -593,7 +587,7 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
   os << "<DartMeasurement name=\"ImageError\" type=\"numeric/double\">";
   os << minError;
   os << "</DartMeasurement>";
-  if ( errIndex <= 0)
+  if (errIndex <= 0)
     {
     os << "<DartMeasurement name=\"BaselineImage\" type=\"text/string\">Standard</DartMeasurement>";
     }
@@ -613,75 +607,75 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
   if (errIndex >= 0)
     {
     newFileName = IncrementFileName(this->ValidImageFileName, errIndex);
-    rt_png->SetFileName(newFileName);
+    rtPng->SetFileName(newFileName);
     delete[] newFileName;
     }
   else
     {
-    rt_png->SetFileName(this->ValidImageFileName);
+    rtPng->SetFileName(this->ValidImageFileName);
     }
 
-  rt_png->Update();
-  rt_id->GetImage()->GetExtent(ext2);
+  rtPng->Update();
+  rtId->GetImage()->GetExtent(ext2);
 
   // If no image differences produced an image, do not write a
   // difference image.
-  if(minError <= 0)
+  if (minError <= 0)
     {
     os << "Image differencing failed to produce an image." << endl;
     return FAILED;
     }
-  if(!(
-      (ext2[1]-ext2[0]) == (ext1[1]-ext1[0]) &&
-      (ext2[3]-ext2[2]) == (ext1[3]-ext1[2]) &&
-      (ext2[5]-ext2[4]) == (ext1[5]-ext1[4])))
+  if (!(
+       (ext2[1] - ext2[0]) == (ext1[1] - ext1[0]) &&
+       (ext2[3] - ext2[2]) == (ext1[3] - ext1[2]) &&
+       (ext2[5] - ext2[4]) == (ext1[5] - ext1[4])))
     {
     os << "Image differencing failed to produce an image because images are "
       "different size:" << endl;
-    os << "Valid image: " << (ext2[1]-ext2[0]) << ", " << (ext2[3]-ext2[2])
-      << ", " << (ext2[5]-ext2[4]) << endl;
-    os << "Test image: " << (ext1[1]-ext1[0]) << ", " << (ext1[3]-ext1[2])
-      << ", " << (ext1[5]-ext1[4]) << endl;
+    os << "Valid image: " << (ext2[1] - ext2[0]) << ", " << (ext2[3] - ext2[2])
+      << ", " << (ext2[5] - ext2[4]) << endl;
+    os << "Test image: " << (ext1[1] - ext1[0]) << ", " << (ext1[3] - ext1[2])
+      << ", " << (ext1[5] - ext1[4]) << endl;
     return FAILED;
     }
 
-  rt_id->Update();
+  rtId->Update();
 
   // test the directory for writing
-  std::string diff_filename = tmpDir + "/" + validName;
-  std::string::size_type dot_pos = diff_filename.rfind(".");
-  if(dot_pos != std::string::npos)
+  string diffFilename = tmpDir + "/" + validName;
+  string::size_type dotPos = diffFilename.rfind(".");
+  if (dotPos != string::npos)
     {
-    diff_filename = diff_filename.substr(0, dot_pos);
+    diffFilename = diffFilename.substr(0, dotPos);
     }
-  diff_filename += ".diff.png";
-  FILE *rt_dout = fopen(diff_filename.c_str(), "wb");
-  if (rt_dout)
+  diffFilename += ".diff.png";
+  FILE *rtDout = fopen(diffFilename.c_str(), "wb");
+  if (rtDout)
     {
-    fclose(rt_dout);
+    fclose(rtDout);
 
     // write out the difference image gamma adjusted for the dashboard
-    VTK_CREATE(vtkImageShiftScale, rt_gamma);
-    rt_gamma->SetInputConnection(rt_id->GetOutputPort());
-    rt_gamma->SetShift(0);
-    rt_gamma->SetScale(10);
+    vtkNew<vtkImageShiftScale> rtGamma;
+    rtGamma->SetInputConnection(rtId->GetOutputPort());
+    rtGamma->SetShift(0);
+    rtGamma->SetScale(10);
 
-    VTK_CREATE(vtkPNGWriter, rt_pngw);
-    rt_pngw->SetFileName(diff_filename.c_str());
-    rt_pngw->SetInputConnection(rt_gamma->GetOutputPort());
-    rt_pngw->Write();
+    vtkNew<vtkPNGWriter> rtPngw;
+    rtPngw->SetFileName(diffFilename.c_str());
+    rtPngw->SetInputConnection(rtGamma->GetOutputPort());
+    rtPngw->Write();
 
     // write out the image that was generated
-    std::string vImage = tmpDir + "/" + validName;
-    rt_pngw->SetFileName(vImage.c_str());
-    rt_pngw->SetInputConnection(imageSource->GetOutputPort());
-    rt_pngw->Write();
+    string vImage = tmpDir + "/" + validName;
+    rtPngw->SetFileName(vImage.c_str());
+    rtPngw->SetInputConnection(imageSource->GetOutputPort());
+    rtPngw->Write();
 
     os <<  "<DartMeasurementFile name=\"TestImage\" type=\"image/png\">";
     os << vImage;
     os << "</DartMeasurementFile>";
     os << "<DartMeasurementFile name=\"DifferenceImage\" type=\"image/png\">";
-    os << diff_filename;
+    os << diffFilename;
     os << "</DartMeasurementFile>";
     os << "<DartMeasurementFile name=\"ValidImage\" type=\"image/png\">";
     os << this->ValidImageFileName;
@@ -694,9 +688,8 @@ int vtkTesting::RegressionTest(vtkAlgorithm* imageSource,
 int vtkTesting::Test(int argc, char *argv[], vtkRenderWindow *rw,
                      double thresh )
 {
-  VTK_CREATE(vtkTesting, testing);
-  int i;
-  for (i = 0; i < argc; ++i)
+  vtkNew<vtkTesting> testing;
+  for (int i = 0; i < argc; ++i)
     {
     testing->AddArgument(argv[i]);
     }
@@ -707,9 +700,9 @@ int vtkTesting::Test(int argc, char *argv[], vtkRenderWindow *rw,
     }
 
   testing->FrontBufferOff();
-  for (i=0; i<argc; i++)
+  for (int i = 0; i < argc; ++i)
     {
-    if ( strcmp("-FrontBuffer", argv[i]) == 0 )
+    if (strcmp("-FrontBuffer", argv[i]) == 0)
       {
       testing->FrontBufferOn();
       }
@@ -725,14 +718,13 @@ int vtkTesting::Test(int argc, char *argv[], vtkRenderWindow *rw,
   return NOT_RUN;
 }
 //-----------------------------------------------------------------------------
-int vtkTesting::CompareAverageOfL2Norm(
-        vtkDataArray *daA,
-        vtkDataArray *daB,
-        double tol)
+int vtkTesting::CompareAverageOfL2Norm(vtkDataArray *daA,
+                                       vtkDataArray *daB,
+                                       double tol)
 {
-  int typeA=daA->GetDataType();
-  int typeB=daB->GetDataType();
-  if (typeA!=typeB)
+  int typeA = daA->GetDataType();
+  int typeB = daB->GetDataType();
+  if (typeA != typeB)
     {
     vtkWarningMacro("Incompatible data types: "
                     << typeA << ","
@@ -740,13 +732,13 @@ int vtkTesting::CompareAverageOfL2Norm(
     return 0;
     }
   //
-  vtkIdType nTupsA=daA->GetNumberOfTuples();
-  vtkIdType nTupsB=daB->GetNumberOfTuples();
-  int nCompsA=daA->GetNumberOfComponents();
-  int nCompsB=daB->GetNumberOfComponents();
+  vtkIdType nTupsA = daA->GetNumberOfTuples();
+  vtkIdType nTupsB = daB->GetNumberOfTuples();
+  int nCompsA = daA->GetNumberOfComponents();
+  int nCompsB = daB->GetNumberOfComponents();
   //
-  if ((nTupsA!=nTupsB)
-     || (nCompsA!=nCompsB))
+  if ((nTupsA != nTupsB)
+     || (nCompsA != nCompsB))
     {
     vtkWarningMacro(
               "Arrays: " << daA->GetName()
@@ -759,26 +751,26 @@ int vtkTesting::CompareAverageOfL2Norm(
     return 0;
     }
 
-  double L2=0.0;
-  vtkIdType N=0;
+  double L2 = 0.0;
+  vtkIdType N = 0;
   switch (typeA)
     {
     case VTK_DOUBLE:
       {
-      vtkDoubleArray *A=vtkDoubleArray::SafeDownCast(daA);
-      double *pA=A->GetPointer(0);
-      vtkDoubleArray *B=vtkDoubleArray::SafeDownCast(daB);
-      double *pB=B->GetPointer(0);
-      N=AccumulateScaledL2Norm(pA,pB,nTupsA,nCompsA,L2);
+      vtkDoubleArray *A = vtkDoubleArray::SafeDownCast(daA);
+      double *pA = A->GetPointer(0);
+      vtkDoubleArray *B = vtkDoubleArray::SafeDownCast(daB);
+      double *pB = B->GetPointer(0);
+      N = AccumulateScaledL2Norm(pA, pB, nTupsA, nCompsA, L2);
       }
       break;
     case VTK_FLOAT:
       {
-      vtkFloatArray *A=vtkFloatArray::SafeDownCast(daA);
-      float *pA=A->GetPointer(0);
-      vtkFloatArray *B=vtkFloatArray::SafeDownCast(daB);
-      float *pB=B->GetPointer(0);
-      N=AccumulateScaledL2Norm(pA,pB,nTupsA,nCompsA,L2);
+      vtkFloatArray *A = vtkFloatArray::SafeDownCast(daA);
+      float *pA = A->GetPointer(0);
+      vtkFloatArray *B = vtkFloatArray::SafeDownCast(daB);
+      float *pB = B->GetPointer(0);
+      N = AccumulateScaledL2Norm(pA, pB, nTupsA, nCompsA, L2);
       }
       break;
     default:
@@ -790,7 +782,7 @@ int vtkTesting::CompareAverageOfL2Norm(
       break;
     }
   //
-  if (N<=0)
+  if (N <= 0)
   {
     return 0;
   }
@@ -805,8 +797,8 @@ int vtkTesting::CompareAverageOfL2Norm(
          << "."  << endl;
     }
   //
-  double avgL2=L2/static_cast<double>(N);
-  if (avgL2>tol)
+  double avgL2 = L2 / static_cast<double>(N);
+  if (avgL2 > tol)
     {
     return 0;
     }
@@ -815,30 +807,28 @@ int vtkTesting::CompareAverageOfL2Norm(
   return 1;
 }
 //-----------------------------------------------------------------------------
-int vtkTesting::CompareAverageOfL2Norm(
-        vtkDataSet *dsA,
-        vtkDataSet *dsB,
-        double tol)
+int vtkTesting::CompareAverageOfL2Norm(vtkDataSet *dsA, vtkDataSet *dsB,
+                                       double tol)
 {
-  vtkDataArray *daA=0;
-  vtkDataArray *daB=0;
-  int status=0;
+  vtkDataArray *daA = 0;
+  vtkDataArray *daB = 0;
+  int status = 0;
 
   // Compare points if the dataset derives from
   // vtkPointSet.
-  vtkPointSet *ptSetA=vtkPointSet::SafeDownCast(dsA);
-  vtkPointSet *ptSetB=vtkPointSet::SafeDownCast(dsB);
-  if (ptSetA!=NULL && ptSetB!=NULL)
+  vtkPointSet *ptSetA = vtkPointSet::SafeDownCast(dsA);
+  vtkPointSet *ptSetB = vtkPointSet::SafeDownCast(dsB);
+  if (ptSetA != NULL && ptSetB != NULL)
     {
     if (this->Verbose)
       {
       cout << "Comparing points:" << endl;
       }
-    daA=ptSetA->GetPoints()->GetData();
-    daB=ptSetB->GetPoints()->GetData();
+    daA = ptSetA->GetPoints()->GetData();
+    daB = ptSetB->GetPoints()->GetData();
     //
-    status=CompareAverageOfL2Norm(daA,daB,tol);
-    if (status==0)
+    status = CompareAverageOfL2Norm(daA, daB, tol);
+    if (status == 0)
       {
       return 0;
       }
@@ -849,9 +839,9 @@ int vtkTesting::CompareAverageOfL2Norm(
     {
     cout << "Comparing data arrays:" << endl;
     }
-  int nDaA=dsA->GetPointData()->GetNumberOfArrays();
-  int nDaB=dsB->GetPointData()->GetNumberOfArrays();
-  if (nDaA!=nDaB)
+  int nDaA = dsA->GetPointData()->GetNumberOfArrays();
+  int nDaB = dsB->GetPointData()->GetNumberOfArrays();
+  if (nDaA != nDaB)
     {
     vtkWarningMacro("Point data, " << dsA
               <<  " and " << dsB << " differ in number of arrays"
@@ -859,13 +849,13 @@ int vtkTesting::CompareAverageOfL2Norm(
     return 0;
     }
   //
-  for (int arrayId=0; arrayId<nDaA; ++arrayId)
+  for (int arrayId = 0; arrayId < nDaA; ++arrayId)
     {
-    daA=dsA->GetPointData()->GetArray(arrayId);
-    daB=dsB->GetPointData()->GetArray(arrayId);
+    daA = dsA->GetPointData()->GetArray(arrayId);
+    daB = dsB->GetPointData()->GetArray(arrayId);
     //
-    status=CompareAverageOfL2Norm(daA,daB,tol);
-    if (status==0)
+    status = CompareAverageOfL2Norm(daA, daB, tol);
+    if (status == 0)
       {
       return 0;
       }
@@ -875,10 +865,10 @@ int vtkTesting::CompareAverageOfL2Norm(
 }
 
 //-----------------------------------------------------------------------------
-int vtkTesting::InteractorEventLoop( int argc,
-                                     char *argv[],
-                                     vtkRenderWindowInteractor *iren,
-                                     const char *playbackStream )
+int vtkTesting::InteractorEventLoop(int argc,
+                                    char *argv[],
+                                    vtkRenderWindowInteractor *iren,
+                                    const char *playbackStream )
 {
   bool disableReplay = false, record = false;
   for (int i = 0; i < argc; i++)
@@ -887,8 +877,7 @@ int vtkTesting::InteractorEventLoop( int argc,
     record        |= (strcmp("--Record", argv[i]) == 0);
     }
 
-  vtkSmartPointer<vtkInteractorEventRecorder> recorder =
-      vtkSmartPointer<vtkInteractorEventRecorder>::New();
+  vtkNew<vtkInteractorEventRecorder> recorder;
   recorder->SetInteractor(iren);
 
   if (!disableReplay)
